# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: araali_api_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61raali_api_service.proto\x12\x12\x61raali_api_service\x1a\x1fgoogle/protobuf/timestamp.proto\")\n\x06Tenant\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x64min_email\x18\x02 \x01(\t\"\x82\x01\n\nAraaliUser\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x31\n\x04role\x18\x02 \x01(\x0e\x32#.araali_api_service.AraaliUser.Role\x12\x15\n\ris_site_admin\x18\x03 \x01(\x08\"\x1b\n\x04Role\x12\t\n\x05\x41\x44MIN\x10\x00\x12\x08\n\x04USER\x10\x01\"A\n\x13\x43reateTenantRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\"{\n\x14\x43reateTenantResponse\x12\x37\n\x08response\x18\x01 \x01(\x0b\x32%.araali_api_service.AraaliAPIResponse\x12*\n\x06tenant\x18\x02 \x01(\x0b\x32\x1a.araali_api_service.Tenant\"A\n\x13\x44\x65leteTenantRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\"j\n\x0e\x41\x64\x64UserRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\x12,\n\x04user\x18\x02 \x01(\x0b\x32\x1e.araali_api_service.AraaliUser\"m\n\x11\x44\x65leteUserRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\x12,\n\x04user\x18\x02 \x01(\x0b\x32\x1e.araali_api_service.AraaliUser\"\x99\x01\n\x11\x41raaliAPIResponse\x12>\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x30.araali_api_service.AraaliAPIResponse.ReturnCode\x12\x0f\n\x07message\x18\x02 \x01(\t\"3\n\nReturnCode\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07\x46\x41ILURE\x10\x01\x12\x0b\n\x07UNKNOWN\x10\x02\"i\n\tTimeSlice\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x7f\n\x0b\x41ssetFilter\x12\x16\n\x0elist_active_vm\x18\x01 \x01(\x08\x12\x18\n\x10list_inactive_vm\x18\x02 \x01(\x08\x12\x1d\n\x15list_active_container\x18\x03 \x01(\x08\x12\x1f\n\x17list_inactive_container\x18\x04 \x01(\x08\"\xb8\x01\n\x11ListAssetsRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\x12\x0c\n\x04zone\x18\x02 \x01(\t\x12\x0b\n\x03\x61pp\x18\x03 \x01(\t\x12+\n\x04time\x18\x04 \x01(\x0b\x32\x1d.araali_api_service.TimeSlice\x12/\n\x06\x66ilter\x18\x05 \x01(\x0b\x32\x1f.araali_api_service.AssetFilter\"x\n\x12ListAssetsResponse\x12\x37\n\x08response\x18\x01 \x01(\x0b\x32%.araali_api_service.AraaliAPIResponse\x12)\n\x06\x61ssets\x18\x02 \x03(\x0b\x32\x19.araali_api_service.Asset\"$\n\x0c\x43\x61pabilities\x12\x14\n\x0c\x63\x61pabilities\x18\x01 \x03(\t\"\xdb\x05\n\x05\x41sset\x12\x11\n\thost_name\x18\x01 \x01(\t\x12\x12\n\nip_address\x18\x02 \x01(\t\x12\x0c\n\x04uuid\x18\x03 \x01(\t\x12\r\n\x05image\x18\x04 \x01(\t\x12\x0c\n\x04zone\x18\x05 \x01(\t\x12\x0c\n\x04\x61pps\x18\x06 \x03(\t\x12\x33\n\x05state\x18\x07 \x01(\x0e\x32$.araali_api_service.Asset.AssetState\x12\x37\n\nasset_type\x18\x08 \x01(\x0e\x32#.araali_api_service.Asset.AssetType\x12:\n\x0fvulnerabilities\x18\t \x03(\x0b\x32!.araali_api_service.Vulnerability\x12\x31\n\x04mode\x18\n \x01(\x0e\x32#.araali_api_service.Asset.AssetMode\x12\x0f\n\x07os_name\x18\x0b \x01(\t\x12\x10\n\x08iam_role\x18\x0c \x01(\t\x12\x19\n\x11\x64ocker_privileged\x18\r \x01(\x08\x12\x32\n\x06\x64ocker\x18\x0e \x01(\x0b\x32 .araali_api_service.CapabilitiesH\x00\x12\x36\n\ncontainerd\x18\x0f \x01(\x0b\x32 .araali_api_service.CapabilitiesH\x00\"3\n\nAssetState\x12\x0b\n\x07\x44\x45LETED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0c\n\x08INACTIVE\x10\x02\"B\n\tAssetType\x12\x11\n\rUNKNOWN_ASSET\x10\x00\x12\x13\n\x0fVIRTUAL_MACHINE\x10\x01\x12\r\n\tCONTAINER\x10\x02\"b\n\tAssetMode\x12\x07\n\x03TAP\x10\x00\x12\n\n\x06INLINE\x10\x01\x12\x1f\n\x1bTRANSITIONING_TAP_TO_INLINE\x10\x02\x12\x1f\n\x1bTRANSITIONING_INLINE_TO_TAP\x10\x03\x42\x0e\n\x0c\x63\x61pabilities\"\xb6\x01\n\rVulnerability\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0e\n\x06\x63ve_id\x18\x02 \x03(\t\x12<\n\x08severity\x18\x03 \x01(\x0e\x32*.araali_api_service.Vulnerability.Severity\"A\n\x08Severity\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03LOW\x10\x01\x12\n\n\x06MEDIUM\x10\x02\x12\x08\n\x04HIGH\x10\x03\x12\x0c\n\x08\x43RITICAL\x10\x04\"\x9d\x02\n\x0b\x41lertFilter\x12\x13\n\x0bopen_alerts\x18\x01 \x01(\x08\x12\x15\n\rclosed_alerts\x18\x02 \x01(\x08\x12\x18\n\x10perimeter_egress\x18\x03 \x01(\x08\x12\x19\n\x11perimeter_ingress\x18\x04 \x01(\x08\x12\x1e\n\x16home_non_araali_egress\x18\x05 \x01(\x08\x12\x1f\n\x17home_non_araali_ingress\x18\x06 \x01(\x08\x12\x18\n\x10\x61raali_to_araali\x18\x07 \x01(\x08\x12\x17\n\x0flist_all_alerts\x18\x08 \x01(\x08\x12+\n\x04time\x18\t \x01(\x0b\x32\x1d.araali_api_service.TimeSlice\x12\x0c\n\x04zone\x18\n \x01(\t\"\x95\x01\n\x11ListAlertsRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\x12/\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x1f.araali_api_service.AlertFilter\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\x12\x14\n\x0cpaging_token\x18\x04 \x01(\t\"\x8c\x01\n\x12ListAlertsResponse\x12\x37\n\x08response\x18\x01 \x01(\x0b\x32%.araali_api_service.AraaliAPIResponse\x12\'\n\x05links\x18\x02 \x03(\x0b\x32\x18.araali_api_service.Link\x12\x14\n\x0cpaging_token\x18\x03 \x01(\t\"\xb7\x01\n\x0e\x41raaliEndpoint\x12\x0c\n\x04zone\x18\x01 \x01(\t\x12\x0b\n\x03\x61pp\x18\x02 \x01(\t\x12\x14\n\x0cunmapped_app\x18\x03 \x01(\t\x12\x11\n\tnamespace\x18\x04 \x01(\t\x12\x0b\n\x03pod\x18\x05 \x01(\t\x12\x16\n\x0e\x63ontainer_name\x18\x06 \x01(\t\x12\x0f\n\x07process\x18\x07 \x01(\t\x12\x13\n\x0b\x62inary_name\x18\x08 \x01(\t\x12\x16\n\x0eparent_process\x18\t \x01(\t\"*\n\x06Subnet\x12\x0e\n\x06subnet\x18\x01 \x01(\t\x12\x10\n\x08net_mask\x18\x02 \x01(\r\"E\n\x17NonAraaliClientEndpoint\x12*\n\x06subnet\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Subnet\"\x81\x01\n\x17NonAraaliServerEndpoint\x12\x15\n\x0b\x64ns_pattern\x18\x01 \x01(\tH\x00\x12,\n\x06subnet\x18\x02 \x01(\x0b\x32\x1a.araali_api_service.SubnetH\x00\x12\x10\n\x08\x64st_port\x18\r \x01(\rB\x0f\n\rdns_or_subnet\"\xb5\x02\n\x11NonAraaliEndpoint\x12=\n\x06\x63lient\x18\x01 \x01(\x0b\x32+.araali_api_service.NonAraaliClientEndpointH\x00\x12=\n\x06server\x18\x02 \x01(\x0b\x32+.araali_api_service.NonAraaliServerEndpointH\x00\x12K\n\x0e\x65ndpoint_group\x18\x03 \x01(\x0e\x32\x33.araali_api_service.NonAraaliEndpoint.EndpointGroup\x12\x14\n\x0corganization\x18\x04 \x01(\t\"7\n\rEndpointGroup\x12\x11\n\rUNKNOWN_GROUP\x10\x00\x12\t\n\x05WORLD\x10\x01\x12\x08\n\x04HOME\x10\x02\x42\x06\n\x04info\"\x85\x01\n\x08\x45ndPoint\x12\x34\n\x06\x61raali\x18\x01 \x01(\x0b\x32\".araali_api_service.AraaliEndpointH\x00\x12;\n\nnon_araali\x18\x02 \x01(\x0b\x32%.araali_api_service.NonAraaliEndpointH\x00\x42\x06\n\x04info\"\xca\x01\n\tAlertInfo\x12 \n\x18\x63ommunication_alert_type\x18\x01 \x01(\t\x12\x1a\n\x12process_alert_type\x18\x02 \x01(\t\x12\x15\n\rre_open_count\x18\x03 \x01(\r\x12\x34\n\x06status\x18\x04 \x01(\x0e\x32$.araali_api_service.AlertInfo.Status\"2\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x08\n\x04OPEN\x10\x01\x12\n\n\x06\x43LOSED\x10\x02\"5\n\x05Ports\x12\x14\n\x0c\x61\x63tive_ports\x18\x01 \x03(\r\x12\x16\n\x0einactive_ports\x18\x02 \x03(\r\"\xb8\x04\n\x04Link\x12,\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x1c.araali_api_service.EndPoint\x12,\n\x06server\x18\x02 \x01(\x0b\x32\x1c.araali_api_service.EndPoint\x12\x39\n\tdirection\x18\x03 \x01(\x0e\x32&.araali_api_service.Link.LinkDirection\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tunique_id\x18\x05 \x01(\t\x12,\n\x05state\x18\x06 \x01(\x0e\x32\x1d.araali_api_service.LinkState\x12(\n\x05ports\x18\x07 \x01(\x0b\x32\x19.araali_api_service.Ports\x12\x33\n\nalert_info\x18\x08 \x01(\x0b\x32\x1d.araali_api_service.AlertInfoH\x00\x12\x35\n\x0bpolicy_info\x18\t \x01(\x0b\x32\x1e.araali_api_service.PolicyInfoH\x00\"\x8a\x01\n\rLinkDirection\x12\x15\n\x11UNKNOWN_DIRECTION\x10\x00\x12\x16\n\x12NON_ARAALI_INGRESS\x10\x01\x12\x12\n\x0e\x41RAALI_INGRESS\x10\x02\x12\x15\n\x11NON_ARAALI_EGRESS\x10\x03\x12\x11\n\rARAALI_EGRESS\x10\x04\x12\x0c\n\x08INTERNAL\x10\x05\x42\x06\n\x04info\"V\n\nPolicyInfo\x12\x15\n\rtemplate_name\x18\x01 \x01(\t\x12\x15\n\rtemplate_user\x18\x02 \x01(\t\x12\x1a\n\x12policy_skip_reason\x18\x03 \x01(\t\"\x97\x01\n\x10ListLinksRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\x12\x0c\n\x04zone\x18\x02 \x01(\t\x12\x0b\n\x03\x61pp\x18\x03 \x01(\t\x12\x0f\n\x07service\x18\x04 \x01(\t\x12+\n\x04time\x18\x05 \x01(\x0b\x32\x1d.araali_api_service.TimeSlice\"u\n\x11ListLinksResponse\x12\x37\n\x08response\x18\x01 \x01(\x0b\x32%.araali_api_service.AraaliAPIResponse\x12\'\n\x05links\x18\x02 \x03(\x0b\x32\x18.araali_api_service.Link\"\xb1\x02\n\x04Lens\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.araali_api_service.Lens.LensType\x12\x0c\n\x04zone\x18\x02 \x01(\t\x12\x0b\n\x03\x61pp\x18\x03 \x01(\t\x12\x0b\n\x03pod\x18\x04 \x01(\t\x12\x16\n\x0e\x63ontainer_name\x18\x05 \x01(\t\x12\x0f\n\x07process\x18\x06 \x01(\t\x12\x16\n\x0eparent_process\x18\x07 \x01(\t\x12\x13\n\x0b\x62inary_name\x18\x08 \x01(\t\x12\x0f\n\x07service\x18\t \x01(\t\"i\n\x08LensType\x12\x10\n\x0cUNKNOWN_LENS\x10\x00\x12\x0c\n\x08ZONE_APP\x10\x01\x12\x0b\n\x07SERVICE\x10\x02\x12\x08\n\x04ZONE\x10\x03\x12\x0b\n\x07PROCESS\x10\x04\x12\r\n\tCONTAINER\x10\x05\x12\n\n\x06TENANT\x10\x06\"]\n\x07Insight\x12\x0e\n\x06reason\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\r\x12&\n\x04lens\x18\x04 \x03(\x0b\x32\x18.araali_api_service.Lens\"O\n\x13ListInsightsRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\x12\x0c\n\x04zone\x18\x02 \x01(\t\"~\n\x14ListInsightsResponse\x12\x37\n\x08response\x18\x01 \x01(\x0b\x32%.araali_api_service.AraaliAPIResponse\x12-\n\x08insights\x18\x02 \x03(\x0b\x32\x1b.araali_api_service.Insight\"\xd8\x01\n\x18\x43reateFortifyYamlRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\x12\x15\n\rworkload_name\x18\x02 \x01(\t\x12\x0b\n\x03\x66og\x18\x03 \x01(\t\x12\x17\n\x0f\x64isable_upgrade\x18\x04 \x01(\x08\x12\x1b\n\x13\x64isable_enforcement\x18\x05 \x01(\x08\x12\x36\n\tyaml_type\x18\x06 \x01(\x0e\x32#.araali_api_service.FortifyYamlType\"k\n\x19\x43reateFortifyYamlResponse\x12\x37\n\x08response\x18\x01 \x01(\x0b\x32%.araali_api_service.AraaliAPIResponse\x12\x15\n\rworkload_yaml\x18\x02 \x01(\t\"|\n\x16ListFortifyYamlRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\x12\x36\n\tyaml_type\x18\x02 \x01(\x0e\x32#.araali_api_service.FortifyYamlType\"e\n\x17ListFortifyYamlResponse\x12\x37\n\x08response\x18\x01 \x01(\x0b\x32%.araali_api_service.AraaliAPIResponse\x12\x11\n\tworkloads\x18\x02 \x03(\t\"]\n\x18\x44\x65leteFortifyYamlRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\x12\x15\n\rworkload_name\x18\x02 \x01(\t\"\x8e\x01\n%ListPolicyAndEnforcementStatusRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\x12\x0c\n\x04zone\x18\x02 \x01(\t\x12\x0b\n\x03\x61pp\x18\x03 \x01(\t\x12\x0b\n\x03pod\x18\x04 \x01(\t\x12\x11\n\tcontainer\x18\x05 \x01(\t\"M\n&ListPolicyAndEnforcementStatusResponse\x12#\n\x1bpolicy_and_enforcement_yaml\x18\x01 \x01(\t\"\xad\x01\n\rAraaliFwKnobs\x12\x0f\n\x07install\x18\x01 \x01(\x08\x12&\n\x1e\x65nable_process_vulnerabilities\x18\x02 \x01(\x08\x12(\n enable_container_vulnerabilities\x18\x03 \x01(\x08\x12\x19\n\x11\x65nable_flow_dedup\x18\x04 \x01(\x08\x12\x1e\n\x16\x65nable_flow_rate_limit\x18\x05 \x01(\x08\";\n\x18GetFirewallConfigRequest\x12\x11\n\ttenant_id\x18\x01 \x01(\t\x12\x0c\n\x04zone\x18\x02 \x01(\t\"p\n\x1bUpdateFirewallConfigRequest\x12\x11\n\ttenant_id\x18\x01 \x01(\t\x12\x0c\n\x04zone\x18\x02 \x01(\t\x12\x30\n\x05knobs\x18\x03 \x01(\x0b\x32!.araali_api_service.AraaliFwKnobs\"k\n\x16\x46irewallConfigResponse\x12\x11\n\ttenant_id\x18\x02 \x01(\t\x12\x0c\n\x04zone\x18\x03 \x01(\t\x12\x30\n\x05knobs\x18\x04 \x01(\x0b\x32!.araali_api_service.AraaliFwKnobs*Z\n\tLinkState\x12\x12\n\x0e\x42\x41SELINE_ALERT\x10\x00\x12\x12\n\x0e\x44\x45\x46INED_POLICY\x10\x01\x12\x12\n\x0eSNOOZED_POLICY\x10\x02\x12\x11\n\rDENIED_POLICY\x10\x03*U\n\x0f\x46ortifyYamlType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x14\n\x10HELM_VALUES_FILE\x10\x01\x12\x1f\n\x1bHELM_CONTROLLER_VALUES_FILE\x10\x02\x32\xd9\x0b\n\tAraaliAPI\x12\x63\n\x0c\x63reateTenant\x12\'.araali_api_service.CreateTenantRequest\x1a(.araali_api_service.CreateTenantResponse\"\x00\x12`\n\x0c\x64\x65leteTenant\x12\'.araali_api_service.DeleteTenantRequest\x1a%.araali_api_service.AraaliAPIResponse\"\x00\x12V\n\x07\x61\x64\x64User\x12\".araali_api_service.AddUserRequest\x1a%.araali_api_service.AraaliAPIResponse\"\x00\x12\\\n\ndeleteUser\x12%.araali_api_service.DeleteUserRequest\x1a%.araali_api_service.AraaliAPIResponse\"\x00\x12]\n\nlistAssets\x12%.araali_api_service.ListAssetsRequest\x1a&.araali_api_service.ListAssetsResponse\"\x00\x12]\n\nlistAlerts\x12%.araali_api_service.ListAlertsRequest\x1a&.araali_api_service.ListAlertsResponse\"\x00\x12Z\n\tlistLinks\x12$.araali_api_service.ListLinksRequest\x1a%.araali_api_service.ListLinksResponse\"\x00\x12\x63\n\x0clistInsights\x12\'.araali_api_service.ListInsightsRequest\x1a(.araali_api_service.ListInsightsResponse\"\x00\x12r\n\x11\x63reateFortifyYaml\x12,.araali_api_service.CreateFortifyYamlRequest\x1a-.araali_api_service.CreateFortifyYamlResponse\"\x00\x12l\n\x0flistFortifyYaml\x12*.araali_api_service.ListFortifyYamlRequest\x1a+.araali_api_service.ListFortifyYamlResponse\"\x00\x12j\n\x11\x64\x65leteFortifyYaml\x12,.araali_api_service.DeleteFortifyYamlRequest\x1a%.araali_api_service.AraaliAPIResponse\"\x00\x12\x99\x01\n\x1elistPolicyAndEnforcementStatus\x12\x39.araali_api_service.ListPolicyAndEnforcementStatusRequest\x1a:.araali_api_service.ListPolicyAndEnforcementStatusResponse\"\x00\x12o\n\x11getFirewallConfig\x12,.araali_api_service.GetFirewallConfigRequest\x1a*.araali_api_service.FirewallConfigResponse\"\x00\x12u\n\x14updateFirewallConfig\x12/.araali_api_service.UpdateFirewallConfigRequest\x1a*.araali_api_service.FirewallConfigResponse\"\x00\x42\x43\n\x10proto.araali.apiB\x0f\x41PIServiceProtoP\x01Z\x1cgolang/v2/araali_api_serviceb\x06proto3')

_LINKSTATE = DESCRIPTOR.enum_types_by_name['LinkState']
LinkState = enum_type_wrapper.EnumTypeWrapper(_LINKSTATE)
_FORTIFYYAMLTYPE = DESCRIPTOR.enum_types_by_name['FortifyYamlType']
FortifyYamlType = enum_type_wrapper.EnumTypeWrapper(_FORTIFYYAMLTYPE)
BASELINE_ALERT = 0
DEFINED_POLICY = 1
SNOOZED_POLICY = 2
DENIED_POLICY = 3
UNKNOWN = 0
HELM_VALUES_FILE = 1
HELM_CONTROLLER_VALUES_FILE = 2


_TENANT = DESCRIPTOR.message_types_by_name['Tenant']
_ARAALIUSER = DESCRIPTOR.message_types_by_name['AraaliUser']
_CREATETENANTREQUEST = DESCRIPTOR.message_types_by_name['CreateTenantRequest']
_CREATETENANTRESPONSE = DESCRIPTOR.message_types_by_name['CreateTenantResponse']
_DELETETENANTREQUEST = DESCRIPTOR.message_types_by_name['DeleteTenantRequest']
_ADDUSERREQUEST = DESCRIPTOR.message_types_by_name['AddUserRequest']
_DELETEUSERREQUEST = DESCRIPTOR.message_types_by_name['DeleteUserRequest']
_ARAALIAPIRESPONSE = DESCRIPTOR.message_types_by_name['AraaliAPIResponse']
_TIMESLICE = DESCRIPTOR.message_types_by_name['TimeSlice']
_ASSETFILTER = DESCRIPTOR.message_types_by_name['AssetFilter']
_LISTASSETSREQUEST = DESCRIPTOR.message_types_by_name['ListAssetsRequest']
_LISTASSETSRESPONSE = DESCRIPTOR.message_types_by_name['ListAssetsResponse']
_CAPABILITIES = DESCRIPTOR.message_types_by_name['Capabilities']
_ASSET = DESCRIPTOR.message_types_by_name['Asset']
_VULNERABILITY = DESCRIPTOR.message_types_by_name['Vulnerability']
_ALERTFILTER = DESCRIPTOR.message_types_by_name['AlertFilter']
_LISTALERTSREQUEST = DESCRIPTOR.message_types_by_name['ListAlertsRequest']
_LISTALERTSRESPONSE = DESCRIPTOR.message_types_by_name['ListAlertsResponse']
_ARAALIENDPOINT = DESCRIPTOR.message_types_by_name['AraaliEndpoint']
_SUBNET = DESCRIPTOR.message_types_by_name['Subnet']
_NONARAALICLIENTENDPOINT = DESCRIPTOR.message_types_by_name['NonAraaliClientEndpoint']
_NONARAALISERVERENDPOINT = DESCRIPTOR.message_types_by_name['NonAraaliServerEndpoint']
_NONARAALIENDPOINT = DESCRIPTOR.message_types_by_name['NonAraaliEndpoint']
_ENDPOINT = DESCRIPTOR.message_types_by_name['EndPoint']
_ALERTINFO = DESCRIPTOR.message_types_by_name['AlertInfo']
_PORTS = DESCRIPTOR.message_types_by_name['Ports']
_LINK = DESCRIPTOR.message_types_by_name['Link']
_POLICYINFO = DESCRIPTOR.message_types_by_name['PolicyInfo']
_LISTLINKSREQUEST = DESCRIPTOR.message_types_by_name['ListLinksRequest']
_LISTLINKSRESPONSE = DESCRIPTOR.message_types_by_name['ListLinksResponse']
_LENS = DESCRIPTOR.message_types_by_name['Lens']
_INSIGHT = DESCRIPTOR.message_types_by_name['Insight']
_LISTINSIGHTSREQUEST = DESCRIPTOR.message_types_by_name['ListInsightsRequest']
_LISTINSIGHTSRESPONSE = DESCRIPTOR.message_types_by_name['ListInsightsResponse']
_CREATEFORTIFYYAMLREQUEST = DESCRIPTOR.message_types_by_name['CreateFortifyYamlRequest']
_CREATEFORTIFYYAMLRESPONSE = DESCRIPTOR.message_types_by_name['CreateFortifyYamlResponse']
_LISTFORTIFYYAMLREQUEST = DESCRIPTOR.message_types_by_name['ListFortifyYamlRequest']
_LISTFORTIFYYAMLRESPONSE = DESCRIPTOR.message_types_by_name['ListFortifyYamlResponse']
_DELETEFORTIFYYAMLREQUEST = DESCRIPTOR.message_types_by_name['DeleteFortifyYamlRequest']
_LISTPOLICYANDENFORCEMENTSTATUSREQUEST = DESCRIPTOR.message_types_by_name['ListPolicyAndEnforcementStatusRequest']
_LISTPOLICYANDENFORCEMENTSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['ListPolicyAndEnforcementStatusResponse']
_ARAALIFWKNOBS = DESCRIPTOR.message_types_by_name['AraaliFwKnobs']
_GETFIREWALLCONFIGREQUEST = DESCRIPTOR.message_types_by_name['GetFirewallConfigRequest']
_UPDATEFIREWALLCONFIGREQUEST = DESCRIPTOR.message_types_by_name['UpdateFirewallConfigRequest']
_FIREWALLCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['FirewallConfigResponse']
_ARAALIUSER_ROLE = _ARAALIUSER.enum_types_by_name['Role']
_ARAALIAPIRESPONSE_RETURNCODE = _ARAALIAPIRESPONSE.enum_types_by_name['ReturnCode']
_ASSET_ASSETSTATE = _ASSET.enum_types_by_name['AssetState']
_ASSET_ASSETTYPE = _ASSET.enum_types_by_name['AssetType']
_ASSET_ASSETMODE = _ASSET.enum_types_by_name['AssetMode']
_VULNERABILITY_SEVERITY = _VULNERABILITY.enum_types_by_name['Severity']
_NONARAALIENDPOINT_ENDPOINTGROUP = _NONARAALIENDPOINT.enum_types_by_name['EndpointGroup']
_ALERTINFO_STATUS = _ALERTINFO.enum_types_by_name['Status']
_LINK_LINKDIRECTION = _LINK.enum_types_by_name['LinkDirection']
_LENS_LENSTYPE = _LENS.enum_types_by_name['LensType']
Tenant = _reflection.GeneratedProtocolMessageType('Tenant', (_message.Message,), {
  'DESCRIPTOR' : _TENANT,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.Tenant)
  })
_sym_db.RegisterMessage(Tenant)

AraaliUser = _reflection.GeneratedProtocolMessageType('AraaliUser', (_message.Message,), {
  'DESCRIPTOR' : _ARAALIUSER,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.AraaliUser)
  })
_sym_db.RegisterMessage(AraaliUser)

CreateTenantRequest = _reflection.GeneratedProtocolMessageType('CreateTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETENANTREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.CreateTenantRequest)
  })
_sym_db.RegisterMessage(CreateTenantRequest)

CreateTenantResponse = _reflection.GeneratedProtocolMessageType('CreateTenantResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATETENANTRESPONSE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.CreateTenantResponse)
  })
_sym_db.RegisterMessage(CreateTenantResponse)

DeleteTenantRequest = _reflection.GeneratedProtocolMessageType('DeleteTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETENANTREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.DeleteTenantRequest)
  })
_sym_db.RegisterMessage(DeleteTenantRequest)

AddUserRequest = _reflection.GeneratedProtocolMessageType('AddUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDUSERREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.AddUserRequest)
  })
_sym_db.RegisterMessage(AddUserRequest)

DeleteUserRequest = _reflection.GeneratedProtocolMessageType('DeleteUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUSERREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.DeleteUserRequest)
  })
_sym_db.RegisterMessage(DeleteUserRequest)

AraaliAPIResponse = _reflection.GeneratedProtocolMessageType('AraaliAPIResponse', (_message.Message,), {
  'DESCRIPTOR' : _ARAALIAPIRESPONSE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.AraaliAPIResponse)
  })
_sym_db.RegisterMessage(AraaliAPIResponse)

TimeSlice = _reflection.GeneratedProtocolMessageType('TimeSlice', (_message.Message,), {
  'DESCRIPTOR' : _TIMESLICE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.TimeSlice)
  })
_sym_db.RegisterMessage(TimeSlice)

AssetFilter = _reflection.GeneratedProtocolMessageType('AssetFilter', (_message.Message,), {
  'DESCRIPTOR' : _ASSETFILTER,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.AssetFilter)
  })
_sym_db.RegisterMessage(AssetFilter)

ListAssetsRequest = _reflection.GeneratedProtocolMessageType('ListAssetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTASSETSREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListAssetsRequest)
  })
_sym_db.RegisterMessage(ListAssetsRequest)

ListAssetsResponse = _reflection.GeneratedProtocolMessageType('ListAssetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTASSETSRESPONSE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListAssetsResponse)
  })
_sym_db.RegisterMessage(ListAssetsResponse)

Capabilities = _reflection.GeneratedProtocolMessageType('Capabilities', (_message.Message,), {
  'DESCRIPTOR' : _CAPABILITIES,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.Capabilities)
  })
_sym_db.RegisterMessage(Capabilities)

Asset = _reflection.GeneratedProtocolMessageType('Asset', (_message.Message,), {
  'DESCRIPTOR' : _ASSET,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.Asset)
  })
_sym_db.RegisterMessage(Asset)

Vulnerability = _reflection.GeneratedProtocolMessageType('Vulnerability', (_message.Message,), {
  'DESCRIPTOR' : _VULNERABILITY,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.Vulnerability)
  })
_sym_db.RegisterMessage(Vulnerability)

AlertFilter = _reflection.GeneratedProtocolMessageType('AlertFilter', (_message.Message,), {
  'DESCRIPTOR' : _ALERTFILTER,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.AlertFilter)
  })
_sym_db.RegisterMessage(AlertFilter)

ListAlertsRequest = _reflection.GeneratedProtocolMessageType('ListAlertsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTALERTSREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListAlertsRequest)
  })
_sym_db.RegisterMessage(ListAlertsRequest)

ListAlertsResponse = _reflection.GeneratedProtocolMessageType('ListAlertsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTALERTSRESPONSE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListAlertsResponse)
  })
_sym_db.RegisterMessage(ListAlertsResponse)

AraaliEndpoint = _reflection.GeneratedProtocolMessageType('AraaliEndpoint', (_message.Message,), {
  'DESCRIPTOR' : _ARAALIENDPOINT,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.AraaliEndpoint)
  })
_sym_db.RegisterMessage(AraaliEndpoint)

Subnet = _reflection.GeneratedProtocolMessageType('Subnet', (_message.Message,), {
  'DESCRIPTOR' : _SUBNET,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.Subnet)
  })
_sym_db.RegisterMessage(Subnet)

NonAraaliClientEndpoint = _reflection.GeneratedProtocolMessageType('NonAraaliClientEndpoint', (_message.Message,), {
  'DESCRIPTOR' : _NONARAALICLIENTENDPOINT,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.NonAraaliClientEndpoint)
  })
_sym_db.RegisterMessage(NonAraaliClientEndpoint)

NonAraaliServerEndpoint = _reflection.GeneratedProtocolMessageType('NonAraaliServerEndpoint', (_message.Message,), {
  'DESCRIPTOR' : _NONARAALISERVERENDPOINT,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.NonAraaliServerEndpoint)
  })
_sym_db.RegisterMessage(NonAraaliServerEndpoint)

NonAraaliEndpoint = _reflection.GeneratedProtocolMessageType('NonAraaliEndpoint', (_message.Message,), {
  'DESCRIPTOR' : _NONARAALIENDPOINT,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.NonAraaliEndpoint)
  })
_sym_db.RegisterMessage(NonAraaliEndpoint)

EndPoint = _reflection.GeneratedProtocolMessageType('EndPoint', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINT,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.EndPoint)
  })
_sym_db.RegisterMessage(EndPoint)

AlertInfo = _reflection.GeneratedProtocolMessageType('AlertInfo', (_message.Message,), {
  'DESCRIPTOR' : _ALERTINFO,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.AlertInfo)
  })
_sym_db.RegisterMessage(AlertInfo)

Ports = _reflection.GeneratedProtocolMessageType('Ports', (_message.Message,), {
  'DESCRIPTOR' : _PORTS,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.Ports)
  })
_sym_db.RegisterMessage(Ports)

Link = _reflection.GeneratedProtocolMessageType('Link', (_message.Message,), {
  'DESCRIPTOR' : _LINK,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.Link)
  })
_sym_db.RegisterMessage(Link)

PolicyInfo = _reflection.GeneratedProtocolMessageType('PolicyInfo', (_message.Message,), {
  'DESCRIPTOR' : _POLICYINFO,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.PolicyInfo)
  })
_sym_db.RegisterMessage(PolicyInfo)

ListLinksRequest = _reflection.GeneratedProtocolMessageType('ListLinksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLINKSREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListLinksRequest)
  })
_sym_db.RegisterMessage(ListLinksRequest)

ListLinksResponse = _reflection.GeneratedProtocolMessageType('ListLinksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLINKSRESPONSE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListLinksResponse)
  })
_sym_db.RegisterMessage(ListLinksResponse)

Lens = _reflection.GeneratedProtocolMessageType('Lens', (_message.Message,), {
  'DESCRIPTOR' : _LENS,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.Lens)
  })
_sym_db.RegisterMessage(Lens)

Insight = _reflection.GeneratedProtocolMessageType('Insight', (_message.Message,), {
  'DESCRIPTOR' : _INSIGHT,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.Insight)
  })
_sym_db.RegisterMessage(Insight)

ListInsightsRequest = _reflection.GeneratedProtocolMessageType('ListInsightsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSIGHTSREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListInsightsRequest)
  })
_sym_db.RegisterMessage(ListInsightsRequest)

ListInsightsResponse = _reflection.GeneratedProtocolMessageType('ListInsightsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSIGHTSRESPONSE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListInsightsResponse)
  })
_sym_db.RegisterMessage(ListInsightsResponse)

CreateFortifyYamlRequest = _reflection.GeneratedProtocolMessageType('CreateFortifyYamlRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFORTIFYYAMLREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.CreateFortifyYamlRequest)
  })
_sym_db.RegisterMessage(CreateFortifyYamlRequest)

CreateFortifyYamlResponse = _reflection.GeneratedProtocolMessageType('CreateFortifyYamlResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFORTIFYYAMLRESPONSE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.CreateFortifyYamlResponse)
  })
_sym_db.RegisterMessage(CreateFortifyYamlResponse)

ListFortifyYamlRequest = _reflection.GeneratedProtocolMessageType('ListFortifyYamlRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFORTIFYYAMLREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListFortifyYamlRequest)
  })
_sym_db.RegisterMessage(ListFortifyYamlRequest)

ListFortifyYamlResponse = _reflection.GeneratedProtocolMessageType('ListFortifyYamlResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFORTIFYYAMLRESPONSE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListFortifyYamlResponse)
  })
_sym_db.RegisterMessage(ListFortifyYamlResponse)

DeleteFortifyYamlRequest = _reflection.GeneratedProtocolMessageType('DeleteFortifyYamlRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFORTIFYYAMLREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.DeleteFortifyYamlRequest)
  })
_sym_db.RegisterMessage(DeleteFortifyYamlRequest)

ListPolicyAndEnforcementStatusRequest = _reflection.GeneratedProtocolMessageType('ListPolicyAndEnforcementStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPOLICYANDENFORCEMENTSTATUSREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListPolicyAndEnforcementStatusRequest)
  })
_sym_db.RegisterMessage(ListPolicyAndEnforcementStatusRequest)

ListPolicyAndEnforcementStatusResponse = _reflection.GeneratedProtocolMessageType('ListPolicyAndEnforcementStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPOLICYANDENFORCEMENTSTATUSRESPONSE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListPolicyAndEnforcementStatusResponse)
  })
_sym_db.RegisterMessage(ListPolicyAndEnforcementStatusResponse)

AraaliFwKnobs = _reflection.GeneratedProtocolMessageType('AraaliFwKnobs', (_message.Message,), {
  'DESCRIPTOR' : _ARAALIFWKNOBS,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.AraaliFwKnobs)
  })
_sym_db.RegisterMessage(AraaliFwKnobs)

GetFirewallConfigRequest = _reflection.GeneratedProtocolMessageType('GetFirewallConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFIREWALLCONFIGREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.GetFirewallConfigRequest)
  })
_sym_db.RegisterMessage(GetFirewallConfigRequest)

UpdateFirewallConfigRequest = _reflection.GeneratedProtocolMessageType('UpdateFirewallConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFIREWALLCONFIGREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.UpdateFirewallConfigRequest)
  })
_sym_db.RegisterMessage(UpdateFirewallConfigRequest)

FirewallConfigResponse = _reflection.GeneratedProtocolMessageType('FirewallConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _FIREWALLCONFIGRESPONSE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.FirewallConfigResponse)
  })
_sym_db.RegisterMessage(FirewallConfigResponse)

_ARAALIAPI = DESCRIPTOR.services_by_name['AraaliAPI']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020proto.araali.apiB\017APIServiceProtoP\001Z\034golang/v2/araali_api_service'
  _LINKSTATE._serialized_start=6997
  _LINKSTATE._serialized_end=7087
  _FORTIFYYAMLTYPE._serialized_start=7089
  _FORTIFYYAMLTYPE._serialized_end=7174
  _TENANT._serialized_start=81
  _TENANT._serialized_end=122
  _ARAALIUSER._serialized_start=125
  _ARAALIUSER._serialized_end=255
  _ARAALIUSER_ROLE._serialized_start=228
  _ARAALIUSER_ROLE._serialized_end=255
  _CREATETENANTREQUEST._serialized_start=257
  _CREATETENANTREQUEST._serialized_end=322
  _CREATETENANTRESPONSE._serialized_start=324
  _CREATETENANTRESPONSE._serialized_end=447
  _DELETETENANTREQUEST._serialized_start=449
  _DELETETENANTREQUEST._serialized_end=514
  _ADDUSERREQUEST._serialized_start=516
  _ADDUSERREQUEST._serialized_end=622
  _DELETEUSERREQUEST._serialized_start=624
  _DELETEUSERREQUEST._serialized_end=733
  _ARAALIAPIRESPONSE._serialized_start=736
  _ARAALIAPIRESPONSE._serialized_end=889
  _ARAALIAPIRESPONSE_RETURNCODE._serialized_start=838
  _ARAALIAPIRESPONSE_RETURNCODE._serialized_end=889
  _TIMESLICE._serialized_start=891
  _TIMESLICE._serialized_end=996
  _ASSETFILTER._serialized_start=998
  _ASSETFILTER._serialized_end=1125
  _LISTASSETSREQUEST._serialized_start=1128
  _LISTASSETSREQUEST._serialized_end=1312
  _LISTASSETSRESPONSE._serialized_start=1314
  _LISTASSETSRESPONSE._serialized_end=1434
  _CAPABILITIES._serialized_start=1436
  _CAPABILITIES._serialized_end=1472
  _ASSET._serialized_start=1475
  _ASSET._serialized_end=2206
  _ASSET_ASSETSTATE._serialized_start=1971
  _ASSET_ASSETSTATE._serialized_end=2022
  _ASSET_ASSETTYPE._serialized_start=2024
  _ASSET_ASSETTYPE._serialized_end=2090
  _ASSET_ASSETMODE._serialized_start=2092
  _ASSET_ASSETMODE._serialized_end=2190
  _VULNERABILITY._serialized_start=2209
  _VULNERABILITY._serialized_end=2391
  _VULNERABILITY_SEVERITY._serialized_start=2326
  _VULNERABILITY_SEVERITY._serialized_end=2391
  _ALERTFILTER._serialized_start=2394
  _ALERTFILTER._serialized_end=2679
  _LISTALERTSREQUEST._serialized_start=2682
  _LISTALERTSREQUEST._serialized_end=2831
  _LISTALERTSRESPONSE._serialized_start=2834
  _LISTALERTSRESPONSE._serialized_end=2974
  _ARAALIENDPOINT._serialized_start=2977
  _ARAALIENDPOINT._serialized_end=3160
  _SUBNET._serialized_start=3162
  _SUBNET._serialized_end=3204
  _NONARAALICLIENTENDPOINT._serialized_start=3206
  _NONARAALICLIENTENDPOINT._serialized_end=3275
  _NONARAALISERVERENDPOINT._serialized_start=3278
  _NONARAALISERVERENDPOINT._serialized_end=3407
  _NONARAALIENDPOINT._serialized_start=3410
  _NONARAALIENDPOINT._serialized_end=3719
  _NONARAALIENDPOINT_ENDPOINTGROUP._serialized_start=3656
  _NONARAALIENDPOINT_ENDPOINTGROUP._serialized_end=3711
  _ENDPOINT._serialized_start=3722
  _ENDPOINT._serialized_end=3855
  _ALERTINFO._serialized_start=3858
  _ALERTINFO._serialized_end=4060
  _ALERTINFO_STATUS._serialized_start=4010
  _ALERTINFO_STATUS._serialized_end=4060
  _PORTS._serialized_start=4062
  _PORTS._serialized_end=4115
  _LINK._serialized_start=4118
  _LINK._serialized_end=4686
  _LINK_LINKDIRECTION._serialized_start=4540
  _LINK_LINKDIRECTION._serialized_end=4678
  _POLICYINFO._serialized_start=4688
  _POLICYINFO._serialized_end=4774
  _LISTLINKSREQUEST._serialized_start=4777
  _LISTLINKSREQUEST._serialized_end=4928
  _LISTLINKSRESPONSE._serialized_start=4930
  _LISTLINKSRESPONSE._serialized_end=5047
  _LENS._serialized_start=5050
  _LENS._serialized_end=5355
  _LENS_LENSTYPE._serialized_start=5250
  _LENS_LENSTYPE._serialized_end=5355
  _INSIGHT._serialized_start=5357
  _INSIGHT._serialized_end=5450
  _LISTINSIGHTSREQUEST._serialized_start=5452
  _LISTINSIGHTSREQUEST._serialized_end=5531
  _LISTINSIGHTSRESPONSE._serialized_start=5533
  _LISTINSIGHTSRESPONSE._serialized_end=5659
  _CREATEFORTIFYYAMLREQUEST._serialized_start=5662
  _CREATEFORTIFYYAMLREQUEST._serialized_end=5878
  _CREATEFORTIFYYAMLRESPONSE._serialized_start=5880
  _CREATEFORTIFYYAMLRESPONSE._serialized_end=5987
  _LISTFORTIFYYAMLREQUEST._serialized_start=5989
  _LISTFORTIFYYAMLREQUEST._serialized_end=6113
  _LISTFORTIFYYAMLRESPONSE._serialized_start=6115
  _LISTFORTIFYYAMLRESPONSE._serialized_end=6216
  _DELETEFORTIFYYAMLREQUEST._serialized_start=6218
  _DELETEFORTIFYYAMLREQUEST._serialized_end=6311
  _LISTPOLICYANDENFORCEMENTSTATUSREQUEST._serialized_start=6314
  _LISTPOLICYANDENFORCEMENTSTATUSREQUEST._serialized_end=6456
  _LISTPOLICYANDENFORCEMENTSTATUSRESPONSE._serialized_start=6458
  _LISTPOLICYANDENFORCEMENTSTATUSRESPONSE._serialized_end=6535
  _ARAALIFWKNOBS._serialized_start=6538
  _ARAALIFWKNOBS._serialized_end=6711
  _GETFIREWALLCONFIGREQUEST._serialized_start=6713
  _GETFIREWALLCONFIGREQUEST._serialized_end=6772
  _UPDATEFIREWALLCONFIGREQUEST._serialized_start=6774
  _UPDATEFIREWALLCONFIGREQUEST._serialized_end=6886
  _FIREWALLCONFIGRESPONSE._serialized_start=6888
  _FIREWALLCONFIGRESPONSE._serialized_end=6995
  _ARAALIAPI._serialized_start=7177
  _ARAALIAPI._serialized_end=8674
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import araali_api_service_pb2 as araali__api__service__pb2


class AraaliAPIStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.createTenant = channel.unary_unary(
                '/araali_api_service.AraaliAPI/createTenant',
                request_serializer=araali__api__service__pb2.CreateTenantRequest.SerializeToString,
                response_deserializer=araali__api__service__pb2.CreateTenantResponse.FromString,
                )
        self.deleteTenant = channel.unary_unary(
                '/araali_api_service.AraaliAPI/deleteTenant',
                request_serializer=araali__api__service__pb2.DeleteTenantRequest.SerializeToString,
                response_deserializer=araali__api__service__pb2.AraaliAPIResponse.FromString,
                )
        self.addUser = channel.unary_unary(
                '/araali_api_service.AraaliAPI/addUser',
                request_serializer=araali__api__service__pb2.AddUserRequest.SerializeToString,
                response_deserializer=araali__api__service__pb2.AraaliAPIResponse.FromString,
                )
        self.deleteUser = channel.unary_unary(
                '/araali_api_service.AraaliAPI/deleteUser',
                request_serializer=araali__api__service__pb2.DeleteUserRequest.SerializeToString,
                response_deserializer=araali__api__service__pb2.AraaliAPIResponse.FromString,
                )
        self.listAssets = channel.unary_unary(
                '/araali_api_service.AraaliAPI/listAssets',
                request_serializer=araali__api__service__pb2.ListAssetsRequest.SerializeToString,
                response_deserializer=araali__api__service__pb2.ListAssetsResponse.FromString,
                )
        self.listAlerts = channel.unary_unary(
                '/araali_api_service.AraaliAPI/listAlerts',
                request_serializer=araali__api__service__pb2.ListAlertsRequest.SerializeToString,
                response_deserializer=araali__api__service__pb2.ListAlertsResponse.FromString,
                )
        self.listLinks = channel.unary_unary(
                '/araali_api_service.AraaliAPI/listLinks',
                request_serializer=araali__api__service__pb2.ListLinksRequest.SerializeToString,
                response_deserializer=araali__api__service__pb2.ListLinksResponse.FromString,
                )
        self.listInsights = channel.unary_unary(
                '/araali_api_service.AraaliAPI/listInsights',
                request_serializer=araali__api__service__pb2.ListInsightsRequest.SerializeToString,
                response_deserializer=araali__api__service__pb2.ListInsightsResponse.FromString,
                )
        self.createFortifyYaml = channel.unary_unary(
                '/araali_api_service.AraaliAPI/createFortifyYaml',
                request_serializer=araali__api__service__pb2.CreateFortifyYamlRequest.SerializeToString,
                response_deserializer=araali__api__service__pb2.CreateFortifyYamlResponse.FromString,
                )
        self.listFortifyYaml = channel.unary_unary(
                '/araali_api_service.AraaliAPI/listFortifyYaml',
                request_serializer=araali__api__service__pb2.ListFortifyYamlRequest.SerializeToString,
                response_deserializer=araali__api__service__pb2.ListFortifyYamlResponse.FromString,
                )
        self.deleteFortifyYaml = channel.unary_unary(
                '/araali_api_service.AraaliAPI/deleteFortifyYaml',
                request_serializer=araali__api__service__pb2.DeleteFortifyYamlRequest.SerializeToString,
                response_deserializer=araali__api__service__pb2.AraaliAPIResponse.FromString,
                )
        self.listPolicyAndEnforcementStatus = channel.unary_unary(
                '/araali_api_service.AraaliAPI/listPolicyAndEnforcementStatus',
                request_serializer=araali__api__service__pb2.ListPolicyAndEnforcementStatusRequest.SerializeToString,
                response_deserializer=araali__api__service__pb2.ListPolicyAndEnforcementStatusResponse.FromString,
                )
        self.getFirewallConfig = channel.unary_unary(
                '/araali_api_service.AraaliAPI/getFirewallConfig',
                request_serializer=araali__api__service__pb2.GetFirewallConfigRequest.SerializeToString,
                response_deserializer=araali__api__service__pb2.FirewallConfigResponse.FromString,
                )
        self.updateFirewallConfig = channel.unary_unary(
                '/araali_api_service.AraaliAPI/updateFirewallConfig',
                request_serializer=araali__api__service__pb2.UpdateFirewallConfigRequest.SerializeToString,
                response_deserializer=araali__api__service__pb2.FirewallConfigResponse.FromString,
                )


class AraaliAPIServicer(object):
    """Missing associated documentation comment in .proto file."""

    def createTenant(self, request, context):
        """Add a tenant
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteTenant(self, request, context):
        """Delete a tenant
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def addUser(self, request, context):
        """Add a user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteUser(self, request, context):
        """Delete a user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def listAssets(self, request, context):
        """Get assets
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def listAlerts(self, request, context):
        """Get alerts
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def listLinks(self, request, context):
        """Get links within a zone/app
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def listInsights(self, request, context):
        """Get tenant wide insights
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def createFortifyYaml(self, request, context):
        """Generate k8s workload/helm values (also registers workloadID)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def listFortifyYaml(self, request, context):
        """List existing k8s workloads
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteFortifyYaml(self, request, context):
        """Delete existing k8s workload
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def listPolicyAndEnforcementStatus(self, request, context):
        """Download policy and enforcement knobs as code.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getFirewallConfig(self, request, context):
        """Get existing Araali firewall config
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateFirewallConfig(self, request, context):
        """Update existing Araali firewall config
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AraaliAPIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'createTenant': grpc.unary_unary_rpc_method_handler(
                    servicer.createTenant,
                    request_deserializer=araali__api__service__pb2.CreateTenantRequest.FromString,
                    response_serializer=araali__api__service__pb2.CreateTenantResponse.SerializeToString,
            ),
            'deleteTenant': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteTenant,
                    request_deserializer=araali__api__service__pb2.DeleteTenantRequest.FromString,
                    response_serializer=araali__api__service__pb2.AraaliAPIResponse.SerializeToString,
            ),
            'addUser': grpc.unary_unary_rpc_method_handler(
                    servicer.addUser,
                    request_deserializer=araali__api__service__pb2.AddUserRequest.FromString,
                    response_serializer=araali__api__service__pb2.AraaliAPIResponse.SerializeToString,
            ),
            'deleteUser': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteUser,
                    request_deserializer=araali__api__service__pb2.DeleteUserRequest.FromString,
                    response_serializer=araali__api__service__pb2.AraaliAPIResponse.SerializeToString,
            ),
            'listAssets': grpc.unary_unary_rpc_method_handler(
                    servicer.listAssets,
                    request_deserializer=araali__api__service__pb2.ListAssetsRequest.FromString,
                    response_serializer=araali__api__service__pb2.ListAssetsResponse.SerializeToString,
            ),
            'listAlerts': grpc.unary_unary_rpc_method_handler(
                    servicer.listAlerts,
                    request_deserializer=araali__api__service__pb2.ListAlertsRequest.FromString,
                    response_serializer=araali__api__service__pb2.ListAlertsResponse.SerializeToString,
            ),
            'listLinks': grpc.unary_unary_rpc_method_handler(
                    servicer.listLinks,
                    request_deserializer=araali__api__service__pb2.ListLinksRequest.FromString,
                    response_serializer=araali__api__service__pb2.ListLinksResponse.SerializeToString,
            ),
            'listInsights': grpc.unary_unary_rpc_method_handler(
                    servicer.listInsights,
                    request_deserializer=araali__api__service__pb2.ListInsightsRequest.FromString,
                    response_serializer=araali__api__service__pb2.ListInsightsResponse.SerializeToString,
            ),
            'createFortifyYaml': grpc.unary_unary_rpc_method_handler(
                    servicer.createFortifyYaml,
                    request_deserializer=araali__api__service__pb2.CreateFortifyYamlRequest.FromString,
                    response_serializer=araali__api__service__pb2.CreateFortifyYamlResponse.SerializeToString,
            ),
            'listFortifyYaml': grpc.unary_unary_rpc_method_handler(
                    servicer.listFortifyYaml,
                    request_deserializer=araali__api__service__pb2.ListFortifyYamlRequest.FromString,
                    response_serializer=araali__api__service__pb2.ListFortifyYamlResponse.SerializeToString,
            ),
            'deleteFortifyYaml': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteFortifyYaml,
                    request_deserializer=araali__api__service__pb2.DeleteFortifyYamlRequest.FromString,
                    response_serializer=araali__api__service__pb2.AraaliAPIResponse.SerializeToString,
            ),
            'listPolicyAndEnforcementStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.listPolicyAndEnforcementStatus,
                    request_deserializer=araali__api__service__pb2.ListPolicyAndEnforcementStatusRequest.FromString,
                    response_serializer=araali__api__service__pb2.ListPolicyAndEnforcementStatusResponse.SerializeToString,
            ),
            'getFirewallConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.getFirewallConfig,
                    request_deserializer=araali__api__service__pb2.GetFirewallConfigRequest.FromString,
                    response_serializer=araali__api__service__pb2.FirewallConfigResponse.SerializeToString,
            ),
            'updateFirewallConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.updateFirewallConfig,
                    request_deserializer=araali__api__service__pb2.UpdateFirewallConfigRequest.FromString,
                    response_serializer=araali__api__service__pb2.FirewallConfigResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'araali_api_service.AraaliAPI', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AraaliAPI(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def createTenant(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/araali_api_service.AraaliAPI/createTenant',
            araali__api__service__pb2.CreateTenantRequest.SerializeToString,
            araali__api__service__pb2.CreateTenantResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteTenant(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/araali_api_service.AraaliAPI/deleteTenant',
            araali__api__service__pb2.DeleteTenantRequest.SerializeToString,
            araali__api__service__pb2.AraaliAPIResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def addUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/araali_api_service.AraaliAPI/addUser',
            araali__api__service__pb2.AddUserRequest.SerializeToString,
            araali__api__service__pb2.AraaliAPIResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/araali_api_service.AraaliAPI/deleteUser',
            araali__api__service__pb2.DeleteUserRequest.SerializeToString,
            araali__api__service__pb2.AraaliAPIResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def listAssets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/araali_api_service.AraaliAPI/listAssets',
            araali__api__service__pb2.ListAssetsRequest.SerializeToString,
            araali__api__service__pb2.ListAssetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def listAlerts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/araali_api_service.AraaliAPI/listAlerts',
            araali__api__service__pb2.ListAlertsRequest.SerializeToString,
            araali__api__service__pb2.ListAlertsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def listLinks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/araali_api_service.AraaliAPI/listLinks',
            araali__api__service__pb2.ListLinksRequest.SerializeToString,
            araali__api__service__pb2.ListLinksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def listInsights(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/araali_api_service.AraaliAPI/listInsights',
            araali__api__service__pb2.ListInsightsRequest.SerializeToString,
            araali__api__service__pb2.ListInsightsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def createFortifyYaml(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/araali_api_service.AraaliAPI/createFortifyYaml',
            araali__api__service__pb2.CreateFortifyYamlRequest.SerializeToString,
            araali__api__service__pb2.CreateFortifyYamlResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def listFortifyYaml(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/araali_api_service.AraaliAPI/listFortifyYaml',
            araali__api__service__pb2.ListFortifyYamlRequest.SerializeToString,
            araali__api__service__pb2.ListFortifyYamlResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteFortifyYaml(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/araali_api_service.AraaliAPI/deleteFortifyYaml',
            araali__api__service__pb2.DeleteFortifyYamlRequest.SerializeToString,
            araali__api__service__pb2.AraaliAPIResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def listPolicyAndEnforcementStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/araali_api_service.AraaliAPI/listPolicyAndEnforcementStatus',
            araali__api__service__pb2.ListPolicyAndEnforcementStatusRequest.SerializeToString,
            araali__api__service__pb2.ListPolicyAndEnforcementStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getFirewallConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/araali_api_service.AraaliAPI/getFirewallConfig',
            araali__api__service__pb2.GetFirewallConfigRequest.SerializeToString,
            araali__api__service__pb2.FirewallConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def updateFirewallConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/araali_api_service.AraaliAPI/updateFirewallConfig',
            araali__api__service__pb2.UpdateFirewallConfigRequest.SerializeToString,
            araali__api__service__pb2.FirewallConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from __future__ import print_function

import datetime
import grpc
from google.protobuf.json_format import MessageToJson
import json

from . import araali_api_service_pb2
from . import araali_api_service_pb2_grpc
from . import utils

g_debug = False

def init_assetsreq(zone, app, ago, tenant=None):
    req = araali_api_service_pb2.ListAssetsRequest()
    
    if tenant is None:
        if utils.cfg["tenant"]: req.tenant.id = utils.cfg["tenant"]
    else:
        req.tenant.id = tenant
    
    if zone: req.zone = zone
    if app: req.app = app

    req.filter.list_active_vm = True
    req.filter.list_inactive_vm = False
    req.filter.list_active_container = True
    req.filter.list_inactive_container = False

    if not ago:
        ago = "days=1"
    ago = dict([utils.make_map(a) for a in ago.split(",")])
    req.time.start_time.FromDatetime(datetime.datetime.utcnow() - datetime.timedelta(**ago))
    req.time.end_time.FromDatetime(datetime.datetime.utcnow())
    
    if g_debug: print(req)

    return req

def init_linksreq(zone, app, svc, ago, tenant=None):
    req = araali_api_service_pb2.ListLinksRequest()
    
    if tenant is None:
        if utils.cfg["tenant"]: req.tenant.id = utils.cfg["tenant"]
    else:
        req.tenant.id = tenant
    if zone: req.zone = zone
    if app: req.app = app
    if svc: req.service = svc

    if not ago:
        ago = "days=1"
    ago = dict([utils.make_map(a) for a in ago.split(",")])
    req.time.start_time.FromDatetime(datetime.datetime.utcnow() - datetime.timedelta(**ago))
    req.time.end_time.FromDatetime(datetime.datetime.utcnow())
    
    if g_debug: print(req)

    return req

def init_alertreq(count, ago, token, tenant=None):
    req = araali_api_service_pb2.ListAlertsRequest()
    
    if tenant is None:
        if utils.cfg["tenant"]: req.tenant.id = utils.cfg["tenant"]
    else:
        req.tenant.id = tenant
    
    req.filter.open_alerts = True
    req.filter.closed_alerts = False
    req.filter.list_all_alerts = False
    req.filter.perimeter_ingress = True
    req.filter.perimeter_egress = True
    req.filter.home_non_araali_ingress = True
    req.filter.home_non_araali_egress = True
    req.filter.araali_to_araali = True
    if not ago:
        ago = "infinite"
    if ago != "infinite":
        ago = dict([utils.make_map(a) for a in ago.split(",")])
        req.filter.time.start_time.FromDatetime(datetime.datetime.utcnow() - datetime.timedelta(**ago))
        req.filter.time.end_time.FromDatetime(datetime.datetime.utcnow())
    
    if count is None: count = 1000
    req.count = count

    if token: req.paging_token = token
    if g_debug: print(req)

    return req

def init_insightsreq(zone, tenant=None):
    req = araali_api_service_pb2.ListInsightsRequest()
    
    if tenant is None:
        if utils.cfg["tenant"]: req.tenant.id = utils.cfg["tenant"]
    else:
        req.tenant.id = tenant
    if zone: req.zone = zone
    
    if g_debug: print(req)

    return req

class API:
    def __init__(self):
        if utils.cfg["token"] is None:
            raise Exception("*** ARAALI_API_TOKEN environment variable is not set")

        class GrpcAuth(grpc.AuthMetadataPlugin):
            def __init__(self, key):
                self._key = key

            def __call__(self, context, callback):
                callback((('authorization', self._key),), None)

        token_cred = grpc.metadata_call_credentials(GrpcAuth("Bearer %s" % utils.cfg["token"]))
        channel_cred = grpc.ssl_channel_credentials()
        creds = grpc.composite_channel_credentials(channel_cred, token_cred)

        backend = utils.cfg["backend"]
        if not backend:
            backend = "prod"
        channel = grpc.secure_channel('api-%s.aws.araalinetworks.com:443' % (backend), creds)

        self.stub = araali_api_service_pb2_grpc.AraaliAPIStub(channel)

    def get_alerts(self, count=None, ago=None, token=None, tenant=None):
        """Fetches alerts
            Usage: alerts, next_page, status = api.get_alerts()
        """
        resp = self.stub.listAlerts(init_alertreq(count, ago, token, tenant))
        if resp.response.code != 0:
            print("*** Error fetching alerts:", resp.response.message)
        return ([json.loads(MessageToJson(a)) for a in resp.links], resp.paging_token, resp.response.code)

    def get_assets(self, zone=None, app=None, ago=None, tenant=None):
        """Fetches assets
            Usage: assets, status = api.get_assets()
        """
        resp = self.stub.listAssets(init_assetsreq(zone, app, ago, tenant))
        if resp.response.code != 0:
            print("*** Error fetching assets:", resp.response.message)
        return ([json.loads(MessageToJson(a)) for a in resp.assets], resp.response.code)

    def get_links(self, zone=None, app=None, svc=None, ago=None, tenant=None):
        """Fetches links
            Usage: links, status = api.get_links()
        """
        resp = self.stub.listLinks(init_linksreq(zone, app, svc, ago, tenant))
        if resp.response.code != 0:
            print("*** Error fetching links:", resp.response.message)
        return ([json.loads(MessageToJson(a)) for a in resp.links], resp.response.code)

    def get_insights(self, zone=None, tenant=None):
        """Fetches insights
            Usage: insights, status = api.get_insights()
        """
        resp = self.stub.listInsights(init_insightsreq(zone, tenant))
        if resp.response.code != 0:
            print("*** Error fetching insights:", resp.response.message)
        return ([json.loads(MessageToJson(a)) for a in resp.insights], resp.response.code)



"""araali package provides API access for python

    Setup (one time):
        # setup a python3 virtualenv to run araali                                      
        cd ~/
        python3 -m venv araaliapienv                                                    
        source araaliapienv/bin/activate                                                
        pip install araali

    Every other time (enter the virtualenv and use it):
        cd ~/
        source araaliapienv/bin/activate                                                
        pip install --upgrade araali

    Usage:
        # export your api token

        export ARAALI_API_TOKEN="<your-token-here>"

        # from python REPL

            >>> import araali                                                               
            >>> help(araali)   

        # from your code

            import araali
            api = araali.API()

            ###
            # alerts
            #   - count is a limit on how many alerts to fetch
            #   - ago is a string, specifying lookback in days, hours, or minutes
            #       eg: ago="days=10,hours=5" etc.
            #   - default for ago is "inifinte" (beginning of life)
            #   - both parameters are optional
            ###
            alerts, page, status = api.get_alerts(count, ago)
            if status == 0:
                print("Got %s alerts" % len(alerts))
                araali.utils.dump_table(alerts)

            ###
            # assets and CVEs
            #   - all args are optional
            #   - you can limit assets in a zone or a (zone,app)
            ###
            assets, status = api.get_assets(zone, app, ago)
            if status == 0:
                araali.utils.dump_table(assets)

            ###
            # polices for apps and services
            #   - either (zone, app) or svc needs to be specified
            #       e.g.: svc="169.254.169.254:80"
            ###
            links, status = api.get_links(zone, app, svc, ago)
            if status == 0:
                araali.utils.dump_table(links)

            ###
            # insights
            #   - zone is optional and can be used to limit insights for a zone
            ###
            insights, status = api.get_insights(zone)
            if status == 0:
                araali.utils.dump_table(insights)

        # The module can also be run from the command line

            python -m pydoc araali                                                          
            python -m araali -h
"""

from . import utils
if utils.cfg["token"]:
    from .api import API
else:
    from .araalictl import API



from __future__ import print_function

import os
import shlex
import subprocess
import yaml

cfg_fname = os.environ['HOME']+"/.araalirc"

def read_config():
    if os.path.isfile(cfg_fname):
        with open(cfg_fname, "r") as f:
            cfg = yaml.load(f, Loader=yaml.SafeLoader)
    else:
        cfg = {}

    if not cfg.get("tenant", None): cfg["tenant"] = None
    if not cfg.get("template_dir", None): cfg["template_dir"] = "../templates"
    if not cfg.get("token", None): cfg["token"] = os.getenv('ARAALI_API_TOKEN')
    if not cfg.get("backend", None): cfg["backend"] = "prod"
    # env variable overrides on disk config
    if os.getenv("ARAALI_BACKEND"):
        cfg["backend"] = os.getenv("ARAALI_BACKEND")
    return cfg

cfg = read_config()

def config(tenant=None, tenants=None, template_dir=None, backend=None):
    global cfg

    def save(cfg):
        with open(cfg_fname, "w") as f:
            cfg2 = dict(cfg)
            del cfg2["token"]
            yaml.dump(cfg2, f)

    if tenant is not None:
        if not tenant: # passed as empty string
            tenant = None # store it as nil in yaml
        cfg["tenant"] = tenant
        save(cfg)
    if tenants is not None:
        cfg["tenants"] = [dict(zip(["name", "id"], a.split(":"))) for a in tenants.split(",")]
        save(cfg)
    for k in ["template_dir", "backend"]:
        if eval(k) is not None:
            cfg[k] = eval(k)
            save(cfg)
    print(yaml.dump(cfg))

def get_by_key(o, k):
    k = k.split(".")
    for a in k:
        o = o.get(a, None)
        if o is None: return "None"
    return o if o is not None else "None"

def dump_table(objs, quiet=False, filterby=None, countby=None, groupby=None):
    class FilterBy(object):
        def __init__(self, filterby):
            if filterby:
                self.filterby = [a.split("=") for a in filterby.split(":")]
            else:
                self.filterby = None
        
        def filter(self, o):
            if self.filterby is None: return True

            match_count = 0
            for f in self.filterby:
                k, v = f
                for a in v.split(","): # like an OR
                    if get_by_key(o, k) == a:
                        match_count += 1
                        break
            # matched all filters, like AND
            if match_count == len(self.filterby):
                return True
            return False

    class CountBy(object):
        def __init__(self, countby, groupby):
            self.countby = countby.split(",") if countby else countby
            self.groupby = groupby.split(",") if groupby else groupby
            if countby:
                if groupby is None:
                    self.groupby_dict = {"global": {}}
                    for c in self.countby:
                        self.groupby_dict["global"][c] = set()
                else:
                    self.groupby_dict = {}

        def count(self, o):
            if self.countby:
                if self.groupby:
                    groupby_key = []
                    for g in self.groupby:
                        groupby_key.append(get_by_key(o, g))
                    groupby_key = ":".join(groupby_key)
                    if groupby_key not in self.groupby_dict:
                        self.groupby_dict[groupby_key] = {}
                        for c in self.countby:
                            self.groupby_dict[groupby_key][c] = set()
                else:
                    groupby_key = "global"

                for k,v in self.groupby_dict[groupby_key].items():
                    v.add(get_by_key(o, k))

        def show(self):
            if not self.countby:
                return

            for g, countby_dict in self.groupby_dict.items():
                print("\n")
                print("="*40, "%s" % g, "="*40)
                if countby:
                    for k,v in countby_dict.items():
                        print("%ss: %s" % (k, len(v)))

    countby = CountBy(countby, groupby)
    filterby = FilterBy(filterby)
    for idx, o in enumerate(objs):
        if not filterby.filter(o): continue
        if not quiet:
            print("%s %s %s" % ("="*40, idx, "="*40))
            print(yaml.dump(o))
        countby.count(o)
    countby.show()


def make_map(kvstr):
    k, v = kvstr.split("=")
    return k, int(v)

def eprint(*args, **kwargs):
    args = [a.decode() for a in args]
    print(*args, file=sys.stderr, **kwargs)

def run_command(command, result=False, strip=True, in_text=None, debug=False, env=os.environ):
    def collect_output(ret, output):
        if output:
            if strip:
                output = output.strip()
            if result:
                ret.append(output.decode())
            else:
                eprint(output)

    if debug:
        print(command, result)
    process = subprocess.Popen(shlex.split(command), stdout=subprocess.PIPE,
                                stdin=subprocess.PIPE,
                                stderr=subprocess.PIPE,
                                env=env)
    ret = []
    if result:
        if in_text:
            outs, errs = process.communicate(input=in_text.encode())
        else:
            outs, errs = process.communicate()
        return process.poll(), outs+errs
    else:
        while True:
            rc = process.poll()
            err = process.stderr.readline()
            out = process.stdout.readline()
            if rc is not None and not out and not err:
                return rc, "\n".join(ret)
            collect_output(ret, out)
            collect_output(ret, err)



import araali
import pytest

@pytest.fixture(scope="session")
def api():
    if araali.utils.cfg["backend"] != "nightly": araali.utils.config(backend="nightly")
    if araali.utils.cfg["tenant"] != "meta-tap": araali.utils.config(tenant="meta-tap")
    return araali.API()

def test_alerts(api):
    alerts = api.get_alerts()
    assert len(alerts[0]) > 0

def test_assets(api):
    assert len(api.get_assets()[0]) > len(api.get_assets("scale")[0])

@pytest.mark.xfail(reason="not implemented in REST")
def test_links(api):
    assert len(api.get_links(zone="scale", app="araali-operator")[0]) > 0
    assert len(api.get_links(svc="169.254.169.254:80")[0]) > 0

def test_insights(api):
    assert len(api.get_insights()[0]) >= len(api.get_insights("scale")[0])

@pytest.mark.xfail(reason="requires araalictl")
def test_templates(api):
    assert len(api.get_templates()[0]) > 0

@pytest.mark.skipif(araali.utils.cfg["token"] is not None, reason="requires araalictl")
def test_token(api):
    tokens = api.token(op="show")[0]
    if "ars_ut" in [a["name"] for a in tokens["tokens"]]:
        api.token(op="delete", name="ars_ut")

    api.token(op="add", name="ars_ut")
    tokens = api.token(op="show")[0]
    assert len([a for a in tokens["tokens"] if a["name"] == "ars_ut"]) == 1

    tokens = api.token(op="delete", name="ars_ut")
    tokens = api.token(op="show")[0]
    assert [a for a in tokens["tokens"] if a["name"] == "ars_ut"] == []

@pytest.mark.skipif(araali.utils.cfg["token"] is not None, reason="requires araalictl")
def test_rbac(api):
    users = api.rbac_show_users()[0]
    assert "meta-tap@araalinetworks.com" in [u["email"] for u in users]



import boto3
from . import utils

def cf_ls(get_all):
        client = boto3.client("cloudformation")
        ret = client.list_stacks()
        while "NextToken" in ret:
            for stack in ret["StackSummaries"]:
                if get_all or "araaliapicf." in stack["StackName"]:
                    if stack["StackStatus"] in ["DELETE_COMPLETE"]: continue
                    yield {"id": stack["StackId"], "name": stack["StackName"],
                            "created": stack["CreationTime"],
                            "status": stack["StackStatus"],
                            "drift": stack["DriftInformation"],
                            }
            ret = client.list_stacks(NextToken=ret["NextToken"])

def cf_rm(name):
    print("removing %s" % name)

def cf_add_vm():
    print("adding vm")

def assets(members):
    curr_account = boto3.client('sts').get_caller_identity().get('Account')
    if members:
        def get_accounts():
            for acc in boto3.client('organizations').list_accounts()["Accounts"]:
                yield acc
        accounts = get_accounts()
    else:
        accounts = [{"Id": curr_account}]
    for acc in accounts:
        if acc["Id"] == curr_account:
            session = boto3.session.Session()
        else:
            role_info = {
                'RoleArn': 'arn:aws:iam::%s:role/OrganizationAccountAccessRole' % acc["Id"],
                'RoleSessionName': 'araaliapi'
            }
            credentials = boto3.client('sts').assume_role(**role_info)
            session = boto3.session.Session(
                aws_access_key_id=credentials['Credentials']['AccessKeyId'],
                aws_secret_access_key=credentials['Credentials']['SecretAccessKey'],
                aws_session_token=credentials['Credentials']['SessionToken']
            )

        ec2_client = session.resource("ec2")
        for instance in ec2_client.instances.all():
            # 'ami_launch_index', 'architecture', 'attach_classic_link_vpc',
            # 'attach_volume', 'block_device_mappings', 'boot_mode',
            # 'capacity_reservation_id', 'capacity_reservation_specification',
            # 'classic_address', 'client_token', 'console_output',
            # 'cpu_options', 'create_image', 'create_tags', 'delete_tags',
            # 'describe_attribute', 'detach_classic_link_vpc', 'detach_volume',
            # 'ebs_optimized', 'elastic_gpu_associations',
            # 'elastic_inference_accelerator_associations', 'ena_support',
            # 'enclave_options', 'get_available_subresources',
            # 'hibernation_options', 'hypervisor', 'iam_instance_profile',
            # 'id', 'image', 'image_id', 'instance_id', 'instance_lifecycle',
            # 'instance_type', 'ipv6_address', 'kernel_id', 'key_name',
            # 'key_pair', 'launch_time', 'licenses', 'load',
            # 'maintenance_options', 'meta', 'metadata_options',
            # 'modify_attribute', 'monitor', 'monitoring',
            # 'network_interfaces', 'network_interfaces_attribute',
            # 'outpost_arn', 'password_data', 'placement', 'placement_group',
            # 'platform', 'platform_details', 'private_dns_name',
            # 'private_dns_name_options', 'private_ip_address',
            # 'product_codes', 'public_dns_name', 'public_ip_address',
            # 'ramdisk_id', 'reboot', 'reload', 'report_status',
            # 'reset_attribute', 'reset_kernel', 'reset_ramdisk',
            # 'reset_source_dest_check', 'root_device_name',
            # 'root_device_type', 'security_groups', 'source_dest_check',
            # 'spot_instance_request_id', 'sriov_net_support', 'start',
            # 'state', 'state_reason', 'state_transition_reason', 'stop',
            # 'subnet', 'subnet_id', 'tags', 'terminate', 'tpm_support',
            # 'unmonitor', 'usage_operation', 'usage_operation_update_time',
            # 'virtualization_type', 'volumes', 'vpc', 'vpc_addresses',
            # 'vpc_id', 'wait_until_exists', 'wait_until_running',
            # 'wait_until_stopped', 'wait_until_terminated'
            #print(dir(instance))
            if instance.state["Name"] == "stopped": continue
            yield {
                    "account": acc["Id"],
                    "image_id": instance.image.id,
                    "instance_id": instance.id,
                    "key_name": instance.key_name,
                    "launch-time": instance.launch_time,
                    "state": instance.state["Name"],
                    "subnet": instance.subnet_id,
                    "platform": instance.platform,
                    "public_ip": instance.public_ip_address,
                    "security_groups": instance.security_groups,
                    "tags": instance.tags,
                    "type": instance.instance_type,
                    "vpc": instance.vpc_id,
            }
